VIDE Voids
==========

The ``VIDE_Voids`` contains the void catalogues. The data is organized following the general hierarchical structure described in :ref:`suite_folders`.

For each hydrodynamic simulation we provide voids identified in the galaxy distribution at redshift 0 with the `VIDE <https://bitbucket.org/cosmicvoids/vide_public/wiki/Home>`_ void finder. 

For each void catalogue we provide a folder with the standard VIDE output that is described `here <https://bitbucket.org/cosmicvoids/vide_public/wiki/Void%20Catalogs%20&%20Analysis>`_.


